#
# spec file for package python-flake8
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without python2
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-flake8
Version:        3.5.0
Release:        lp150.2.3
Summary:        Modular source code checker: pep8, pyflakes and co
License:        MIT
Group:          Development/Languages/Python
Url:            https://gitlab.com/pycqa/flake8
Source:         https://files.pythonhosted.org/packages/source/f/flake8/flake8-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module mccabe >= 0.2.1}
BuildRequires:  %{python_module mock >= 2.0.0}
BuildRequires:  %{python_module pycodestyle >= 2.0.0}
BuildRequires:  %{python_module pyflakes >= 1.5.0}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
%if %{with python2}
BuildRequires:  python2-configparser
BuildRequires:  python2-enum34
%endif
# /SECTION
Requires:       python-mccabe >= 0.6.0
Requires:       python-pycodestyle >= 2.0.0
Requires:       python-pyflakes >= 1.5.0
%ifpython2
Requires:       python-configparser
Requires:       python-enum34
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Flake8 is a wrapper around these tools:

- PyFlakes
- pep8
- Ned Batchelder's McCabe script

Flake8 runs all the tools by launching the single ``flake8`` script.

%prep
%setup -q -n flake8-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/flake8
%fdupes %{buildroot}%{_prefix}

%post
%python_install_alternative flake8

%postun
%python_uninstall_alternative flake8

%check
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.rst
%python_alternative %{_bindir}/flake8
%{python_sitelib}/*

%changelog
* Thu Jan 11 2018 tchvatal@suse.com
- Fix build with python3 only, add condition for the py2 only deps
* Tue Oct 24 2017 dmueller@suse.com
- update to 3.5.0:
  - Start using new PyCodestyle checks for bare excepts and ambiguous identifier
  drop 0001-Update-pyflakes-range-and-include-doc-links.patch: upstream
* Wed Oct 18 2017 alarrosa@suse.com
- update to 3.4.1
- Add 0001-Update-pyflakes-range-and-include-doc-links.patch from upstream
  in order to allow using pyflakes >= 1.6.0
* Fri Mar 24 2017 jmatejek@suse.com
- update for singlespec
- update to 3.3.0
  * fix setuptools integration
  * drop python 2.6 and python < 3.4 support
  * nonzero exit on problems
  * python 3.6 support
  * performance improvements
- switch requirement from pep8 to pycodestyle
- switch test runner from nose to pytest
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Jan 13 2016 toddrme2178@gmail.com
- Update to 2.5.1
  * Bug Properly look for .flake8 in current working directory
  * Bug Monkey-patch pep8.stdin_get_value to cache the actual value
    in stdin. This helps plugins relying on the function when run
    with multiprocessing.
- Update to 2.5.0
  * Improvement Raise cap on PyFlakes for Python 3.5 support
  * Improvement Avoid deprecation warnings when loading extensions
  * Improvement Separate logic to enable “off-by-default” extensions
  * Bug Properly parse options to setuptools Flake8 command
  * Bug Fix exceptions when output on stdout is truncated before
    Flake8 finishes writing the output
  * Bug Fix error on OS X where Flake8 can no longer acquire or
    create new semaphores
- Update to 2.4.1
  * Bug Do not raise a SystemError unless there were errors in the
    setuptools command.
  * Bug Do not verify dependencies of extensions loaded via
    entry-points.
  * Improvement Blacklist versions of pep8 we know are broken
- Update to 2.4.0
  * Bug Print filenames when using multiprocessing and -q option.
  * Bug Put upper cap on dependencies. The caps for 2.4.0 are:
    > pep8 < 1.6 (Related to GitLab#35)
    > mccabe < 0.4
    > pyflakes < 0.9
  * See also GitLab#32
  * Bug Files excluded in a config file were not being excluded
    when flake8 was run from a git hook.
  * Improvement Print warnings for users who are providing
    mutually exclusive options to flake8.
  * Feature Allow git hook configuration to live in .git/config.
    See the updated VCS hooks docs for more details.
- Remove upstream-included flake8-fix-tests-using-new-mock.patch
- Implement update-alternatives
* Mon Aug 10 2015 mlin@suse.com
- Add upstream patch flake8-fix-tests-using-new-mock.patch
  * Fix tests using mock 1.1.x and above
* Thu Feb 26 2015 tbechtold@suse.com
- update to 2.3.0
  - Add ``--output-file`` option to specify a file to write to
    instead of ``stdout``.
  - Fix interleaving of output while using multiprocessing
  - Flush standard out when using multiprocessing
  - Make the check for "# flake8: noqa" more strict
  - Fix bugs triggered by turning multiprocessing on by default (again)
  - Passing something in via stdin
  - Analyzing a diff
  - Using windows
  - Fix --install-hook when there are no config files present for pep8 or
    flake8.
  - Fix how the setuptools command parses excludes in config files
  - Fix how the git hook determines which files to analyze (Thanks Chris
    Buccella!)
* Mon Sep 15 2014 tbechtold@suse.com
- update to 2.2.3:
  * Actually turn multiprocessing on by default
- Update Requires for pyflakes, pep8 and mccabe
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 2.2.2
  - Re-enable multiprocessing by default while fixing the issue
    Windows users were seeing.
- Update to 2.2.1
  - Turn off multiple jobs by default. To enable automatic use
    of all CPUs, use --jobs=auto. Fixes #155 and #154.
* Fri Jun 27 2014 dmueller@suse.com
- update to 2.2.0:
  - New option ``doctests`` to run Pyflakes checks on doctests too
  - New option ``jobs`` to launch multiple jobs in parallel
  - Turn on using multiple jobs by default using the CPU count
  - Add support for ``python -m flake8`` on Python 2.7 and Python 3
  - Fix Git and Mercurial hooks: issues #88, #133, #148 and #149
  - Fix crashes with Python 3.4 by upgrading dependencies
  - Fix traceback when running tests with Python 2.6
  - Fix the setuptools command ``python setup.py flake8`` to read
    the project configuration
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.1.0:
  - Add FLAKE8_LAZY and FLAKE8_IGNORE environment variable support to git and
    mercurial hooks
  - Force git and mercurial hooks to repsect configuration in setup.cfg
  - Only check staged files if that is specified
  - Fix hook file permissions
  - Fix the git hook on python 3
  - Ignore non-python files when running the git hook
  - Ignore .tox directories by default
  - Flake8 now reports the column number for PyFlakes messages
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr 24 2013 speilicke@suse.com
- Spec file cleanup
- Run testsuite
- Add LICENSE (for legal)
* Sun Apr 21 2013 dmueller@suse.com
- Initial package (2.0)
